@@ -11,34 +11,29 @@ use fields qw/
     _workers_sig_count
     /;
 
-use POE qw/
-    Wheel::Run
-    Filter::Reference
-    /;
-
-use version;
+use POE qw/Wheel::Run Filter::Reference/;
 
 =head1 NAME
 
-Poe::Wheel::Spawner - A simple subprocess spawner
+Poe::Wheel::Spawner
 
 =head1 DESCRIPTION
 
-Poe::Wheel::Spawner starts on L<run|/run(%arg)> only one subprocess for the L<workload|/new(%arg)>. Until number of subprocesses does not exceed L<pool_size|/new(%arg)> each subprocess can L<spawn|/spawn($pid)> another one.
+Poe::Wheel::Spawner generate only one process for your workload and will add a next one on spawn call in it unless poos_size is not exceeded.
 
 =head1 VERSION
 
-Version v0.021.2
+Version 0.01
 
 =cut
 
-$Poe::Wheel::Spawner::VERSION = version->declare("0.021.2");
+$Poe::Wheel::Spawner::VERSION = '0.01';
 
 =head1 SYNOPSIS
 
-    use POE::Wheel::Spawner;
+    use M43::POE::Wheel::Spawner;
 
-    my $foo = POE::Wheel::Spawner->new(
+    my $foo = M43::POE::Wheel::Spawner->new(
                 pool_size => 2,
                 stop_if_done => 1,
                 workload => sub { _workload() }
@@ -47,8 +42,8 @@ $Poe::Wheel::Spawner::VERSION = version->declare("0.021.2");
     $foo->run();
 
     sub _workload {
-
-        # request for a new sibling
+        
+        # request for a a new sibling
         $foo->spawn($$);
 
         # ...
@@ -56,31 +51,27 @@ $Poe::Wheel::Spawner::VERSION = version->declare("0.021.2");
 
 =head1 SUBROUTINES/METHODS
 
-=head2 new(%arg)
+=cut
 
-Arguments:
+=head2 new(%opts)
+
+B<%opts> keys:
 
 =over
 
-=item
+=item pool_size
 
-pool_size
+the number of maximal parallel executed B<workload>s
 
-the number of maximal parallel executed C<workload>
+=item stop_if_done
 
-=item
+stop after B<pool_size> pid's are exited.
 
-stop_if_done
+run endless if !B<stop_if_done>
 
-stop after all C<pool_size> pid's are exited.
+=item workload
 
-run endless if !C<stop_if_done>
-
-=item
-
-workload
-
-CODE reference to be executed
+CODE reference to execute
 
 =back
 
@@ -109,40 +100,36 @@ sub new {
     return $self;
 } ## end sub new
 
-=head2 run(%arg)
+=head2 run(%opts)
 
-optional C<%arg> arguments for L<POE::Session>:
+%opts provide to POE::Session
 
 =over
 
-=item
-
-debug
+=item debug
 
 default 0
 
-=item
-
-trace
+=item trace
 
 default 0
 
 =back
 
-create a L<POE::Session>
+create a POE::Session
 
-run L<POE::Kernel>
+run POE::Kernel
 
 =cut
 
 sub run {
-    my ($self, %arg) = @_;
+    my ($self, %opts) = @_;
 
     ref($self->{workload}) eq 'CODE'
         || die "work_method is not a code reference";
 
     POE::Session->create(
-        options => { debug => $arg{debug} || 0, trace => $arg{trace} || 0 },
+        options => { debug => $opts{debug} || 0, trace => $opts{trace} || 0 },
         object_states => [
             $self => {
                 _start     => '_handle_start',
@@ -160,7 +147,7 @@ sub run {
 
 =head2 spawn($pid)
 
-request to spawn
+print { busy_worker_pid => $pid } to stdout
 
 =cut
 
@@ -172,13 +159,13 @@ sub spawn {
     print @$output;
 } ## end sub spawn
 
-#=head2 _handle_start
-#
-#handle C<_start> and C<_next> events defined in POE::Session, which is initialized in C<run>.
-#
-#start execution of C<workload> by C<pool_size> parallel running pids
-#
-#=cut
+=head2 _handle_start
+
+handle B<_start> and B<_next> events defined in POE::Session, which is initialized in B<run>.
+
+start execution of B<workload> by B<pool_size> parallel running pids
+
+=cut
 
 sub _handle_start {
     my ($self, $kernel, $heap) = @_[OBJECT, KERNEL, HEAP];
@@ -198,11 +185,11 @@ sub _handle_start {
     $kernel->sig_child($w->PID, "_sig_child");
 } ## end sub _handle_start
 
-#=head2 _handle_sig_child
-#
-#Clear heap. Trigger '_next' if !stop_if_done and currently no child is busy
-#
-#=cut
+=head2 _handle_sig_child
+
+Clear heap. Trigger '_next' if !stop_if_done and currently no child is busy
+
+=cut
 
 sub _handle_sig_child {
     my ($self, $kernel, $heap, $pid, $exit_val)
@@ -226,32 +213,32 @@ sub _handle_sig_child {
     }
 } ## end sub _handle_sig_child
 
-#=head2 _handle_done
-#
-#is not implemented yet
-#
-#=cut
+=head2 _handle_done
+
+is not implemented yet
+
+=cut
 
 sub _handle_done { }
 
-#=head2 _handle_stderr
-#
-#provide STDERR to POE::Kernel::_warn
-#
-#=cut
+=head2 _handle_stderr
+
+provide STDERR to POE::Kernel::_warn
+
+=cut
 
 sub _handle_stderr {
     my ($self, $input, $wheel_id) = @_[OBJECT, ARG0, ARG1];
     POE::Kernel::_warn("wheel $wheel_id STDERR: $input");
 }
 
-#=head2 _handle_stdout
-#
-#evaluate from child to stdout printed result.
-#
-#trigger _next event if child asks - by using busy_worker_pid printed to stdout - for a sibling
-#
-#=cut
+=head2 _handle_stdout
+
+evaluate from child to stdout printed result.
+
+trigger _next event if child asks - by using busy_worker_pid printed to stdout - for a sibling
+
+=cut
 
 sub _handle_stdout {
     my ($self, $kernel, $heap, $result) = @_[OBJECT, KERNEL, HEAP, ARG0];
@@ -267,6 +254,42 @@ sub _handle_stdout {
 
 Alexei Pastuchov E<lt>palik at cpan.orgE<gt>.
 
+=head1 BUGS
+
+Please report any bugs or feature requests to C<bug-poe-wheel-spawner at rt.cpan.org>, or through
+the web interface at L<http://rt.cpan.org/NoAuth/ReportBug.html?Queue=Poe-Wheel-Spawner>.  I will be notified, and then you'll
+automatically be notified of progress on your bug as I make changes.
+
+=head1 SUPPORT
+
+You can find documentation for this module with the perldoc command.
+
+    perldoc Poe::Wheel::Spawner
+
+
+You can also look for information at:
+
+=over 4
+
+=item * RT: CPAN's request tracker (report bugs here)
+
+L<http://rt.cpan.org/NoAuth/Bugs.html?Dist=Poe-Wheel-Spawner>
+
+=item * AnnoCPAN: Annotated CPAN documentation
+
+L<http://annocpan.org/dist/Poe-Wheel-Spawner>
+
+=item * CPAN Ratings
+
+L<http://cpanratings.perl.org/d/Poe-Wheel-Spawner>
+
+=item * Search CPAN
+
+L<http://search.cpan.org/dist/Poe-Wheel-Spawner/>
+
+=back
+
+
 =head1 REPOSITORY
 
 L<https://github.com/p-alik/Poe-Wheel-Spawner.git>
@@ -274,7 +297,7 @@ L<https://github.com/p-alik/Poe-Wheel-Spawner.git>
 =head1 LICENSE AND COPYRIGHT
 
 
-Copyright 2014-2016 by Alexei Pastuchov E<lt>palik at cpan.orgE<gt>.
+Copyright 2014 by Alexei Pastuchov E<lt>palik at cpan.orgE<gt>.
 
 This library is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself.
